@@ -1,6 +1,7 @@
 "cca.default" <-
     function (X, Y, Z, ...) 
 {
+    ZERO <- 1e-04
     CCA <- NULL
     pCCA <- NULL
     CA <- NULL
@@ -30,43 +31,55 @@
         Q <- qr(Z.r)
         Z <- qr.fitted(Q, Xbar)
         tmp <- sum(svd(Z, nu = 0, nv = 0)$d^2)
-        pCCA <- list(rank = Q$rank, tot.chi = tmp, QR = Q, Fit = Z)
-        Xbar <- qr.resid(Q, Xbar)
+        if (Q$rank) {
+            pCCA <- list(rank = Q$rank, tot.chi = tmp, QR = Q, 
+                         Fit = Z)
+            Xbar <- qr.resid(Q, Xbar)
+        }
     }
     else Z.r <- NULL
     if (!missing(Y) && !is.null(Y)) {
         Y <- as.matrix(Y)
         rawmat <- Y
         Y.r <- weight.centre(Y, rowsum)
-        Q <- qr(cbind(Y.r, Z.r))
+        Q <- qr(cbind(Z.r, Y.r), tol = ZERO)
         if (is.null(pCCA)) 
             rank <- Q$rank
         else rank <- Q$rank - pCCA$rank
         Y <- qr.fitted(Q, Xbar)
         sol <- svd(Y)
-        rank <- min(rank, length(sol$d))
+        rank <- min(rank, sum(sol$d > ZERO))
         ax.names <- paste("CCA", 1:length(sol$d), sep = "")
         colnames(sol$u) <- ax.names
         colnames(sol$v) <- ax.names
         names(sol$d) <- ax.names
         rownames(sol$u) <- rownames(X)
         rownames(sol$v) <- colnames(X)
-        CCA <- list(eig = sol$d[1:rank]^2)
-        CCA$u <- sweep(as.matrix(sol$u[, 1:rank, drop = FALSE]), 
-                       1, 1/sqrt(rowsum), "*")
-        CCA$v <- sweep(as.matrix(sol$v[, 1:rank, drop = FALSE]), 
-                       1, 1/sqrt(colsum), "*")
-        CCA$u.eig <- sweep(CCA$u, 2, sol$d[1:rank], "*")
-        CCA$v.eig <- sweep(CCA$v, 2, sol$d[1:rank], "*")
-        CCA$wa.eig <- sweep(Xbar %*% sol$v[, 1:rank, drop = FALSE], 
-                            1, 1/sqrt(rowsum), "*")
-        CCA$wa <- sweep(CCA$wa.eig, 2, 1/sol$d[1:rank], "*")
-        CCA$biplot <- cor(Y.r, sol$u[, 1:rank, drop = FALSE])
-        CCA$rank <- rank
-        CCA$tot.chi <- sum(CCA$eig)
-        CCA$QR <- Q
-        CCA$Xbar <- Xbar
-        Xbar <- qr.resid(Q, Xbar)
+        if (rank) {
+            CCA <- list(eig = sol$d[1:rank]^2)
+            CCA$u <- sweep(as.matrix(sol$u[, 1:rank, drop = FALSE]), 
+                           1, 1/sqrt(rowsum), "*")
+            CCA$v <- sweep(as.matrix(sol$v[, 1:rank, drop = FALSE]), 
+                           1, 1/sqrt(colsum), "*")
+            CCA$u.eig <- sweep(CCA$u, 2, sol$d[1:rank], "*")
+            CCA$v.eig <- sweep(CCA$v, 2, sol$d[1:rank], "*")
+            CCA$wa.eig <- sweep(Xbar %*% sol$v[, 1:rank, drop = FALSE], 
+                                1, 1/sqrt(rowsum), "*")
+            CCA$wa <- sweep(CCA$wa.eig, 2, 1/sol$d[1:rank], "*")
+            oo <- Q$pivot
+             if (!is.null(pCCA$rank))
+                oo <- oo[-(1:pCCA$rank)] - ncol(Z.r) 
+            oo <- oo[1:rank]
+            if (length(oo) < ncol(Y.r)) 
+                CCA$alias <- colnames(Y.r)[-oo]
+            CCA$biplot <- cor(Y.r[, oo, drop = FALSE], sol$u[, 
+                                        1:rank, drop = FALSE])
+            CCA$rank <- rank
+            CCA$tot.chi <- sum(CCA$eig)
+            CCA$QR <- Q
+            CCA$Xbar <- Xbar
+            Xbar <- qr.resid(Q, Xbar)
+        }
     }
     Q <- qr(Xbar)
     if (Q$rank > 0) {
@@ -77,16 +90,19 @@
         names(sol$d) <- ax.names
         rownames(sol$u) <- rownames(X)
         rownames(sol$v) <- colnames(X)
-        CA <- list(eig = sol$d[1:Q$rank]^2)
-        CA$u <- sweep(as.matrix(sol$u[, 1:Q$rank, drop = FALSE]), 
-                      1, 1/sqrt(rowsum), "*")
-        CA$v <- sweep(as.matrix(sol$v[, 1:Q$rank, drop = FALSE]), 
-                      1, 1/sqrt(colsum), "*")
-        CA$u.eig <- sweep(CA$u, 2, sol$d[1:Q$rank], "*")
-        CA$v.eig <- sweep(CA$v, 2, sol$d[1:Q$rank], "*")
-        CA$rank <- Q$rank
-        CA$tot.chi <- sum(CA$eig)
-        CA$Xbar <- Xbar
+        rank <- min(Q$rank, sum(sol$d > ZERO))
+        if (rank) {
+            CA <- list(eig = sol$d[1:rank]^2)
+            CA$u <- sweep(as.matrix(sol$u[, 1:rank, drop = FALSE]), 
+                          1, 1/sqrt(rowsum), "*")
+            CA$v <- sweep(as.matrix(sol$v[, 1:rank, drop = FALSE]), 
+                          1, 1/sqrt(colsum), "*")
+            CA$u.eig <- sweep(CA$u, 2, sol$d[1:rank], "*")
+            CA$v.eig <- sweep(CA$v, 2, sol$d[1:rank], "*")
+            CA$rank <- rank
+            CA$tot.chi <- sum(CA$eig)
+            CA$Xbar <- Xbar
+        }
     }
     call <- match.call()
     call[[1]] <- as.name("cca")
