@@ -1,9 +1,9 @@
 "ordigrid" <-
-    function (ord, levels, replicates, display = "sites", ...) 
+function (ord, levels, replicates, display = "sites", ...) 
 {
     pts <- scores(ord, display = display, ...)
     npoints <- nrow(pts)
-    gr <- gl(levels, replicates, )
+    gr <- gl(levels, replicates, npoints)
     ordisegments(pts, groups = gr, ...)
     gr <- gl(replicates, levels, npoints)
     ordisegments(pts, groups = gr, ...)
